@@ -1,4 +1,11 @@
-"use strict";
+/** @license React v17.0.2
+ * react-jsx-runtime.profiling.min.js
+ *
+ * Copyright (c) Facebook, Inc. and its affiliates.
+ *
+ * This source code is licensed under the MIT license found in the
+ * LICENSE file in the root directory of this source tree.
+ */ "use strict";
 require("object-assign");
 var f = require("react"), g = 60103;
 exports.Fragment = 60107;
