@@ -541,15 +541,18 @@ test!(
         decorators: true,
         ..Default::default()
     }),
-    |_| {
+    |t| {
         let mark = Mark::fresh(Mark::root());
         chain!(
             resolver_with_mark(mark),
             strip(mark),
-            class_properties(class_properties::Config {
-                set_public_fields: true,
-                ..Default::default()
-            }),
+            class_properties(
+                Some(t.comments.clone()),
+                class_properties::Config {
+                    set_public_fields: true,
+                    ..Default::default()
+                }
+            ),
             tr()
         )
     },
@@ -587,15 +590,18 @@ test!(
         decorators: true,
         ..Default::default()
     }),
-    |_| {
+    |t| {
         let mark = Mark::fresh(Mark::root());
         chain!(
             resolver_with_mark(mark),
             strip(mark),
-            class_properties(class_properties::Config {
-                set_public_fields: true,
-                ..Default::default()
-            }),
+            class_properties(
+                Some(t.comments.clone()),
+                class_properties::Config {
+                    set_public_fields: true,
+                    ..Default::default()
+                }
+            ),
             tr(),
         )
     },
@@ -695,15 +701,18 @@ test!(
         decorators: true,
         ..Default::default()
     }),
-    |_| {
+    |t| {
         let mark = Mark::fresh(Mark::root());
         chain!(
             resolver_with_mark(mark),
             strip(mark),
-            class_properties(class_properties::Config {
-                set_public_fields: true,
-                ..Default::default()
-            }),
+            class_properties(
+                Some(t.comments.clone()),
+                class_properties::Config {
+                    set_public_fields: true,
+                    ..Default::default()
+                }
+            ),
             tr(),
         )
     },
